@@ -1,5 +1,5 @@
 package List::Compare::Functional;
-$VERSION = 0.44;
+$VERSION = 0.45;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
     get_intersection
@@ -166,37 +166,27 @@ sub get_unique_all {
 }
 
 sub _unique_engine {
-    my $tested = pop(@_);
-    my $seenrefsref = _calc_seen1(@_);
-    my ($seenref, $xintersectionref) =
-        _calculate_seen_xintersection_only($seenrefsref);
-    my %seen = %{$seenref};
-    my %xintersection = %{$xintersectionref};
+    my $index = pop(@_);
+    my $seenref = _calculate_seen_only(_calc_seen1(@_));
 
-    # Calculate %xunique
-    my (%xunique);
-    for (my $i = 0; $i <= $#{$seenrefsref}; $i++) {
-        my %seenthis = %{$seen{$i}};
-        my (@uniquethis, %deductions, %alldeductions);
-        # Get those elements of %xintersection which we'll need
-        # to subtract from %seenthis
-        foreach (keys %xintersection) {
-            my ($left, $right) = split /_/, $_;
-            if ($left == $i || $right == $i) {
-                $deductions{$_} = $xintersection{$_};
+    my %seen_in_all_others = ();
+    my @seenthis = ();
+    for my $i (keys %{$seenref}) {
+        unless ($i == $index) {
+            for my $k (keys %{$seenref->{$i}}) {
+                $seen_in_all_others{$k}++;
             }
         }
-        foreach my $ded (keys %deductions) {
-            foreach (keys %{$deductions{$ded}}) {
-                $alldeductions{$_}++;
-            }
+        else {
+            @seenthis = keys %{$seenref->{$index}};
         }
-        foreach (keys %seenthis) {
-            push(@uniquethis, $_) unless ($alldeductions{$_});
-        }
-        $xunique{$i} = \@uniquethis;
     }
-    return [ @{$xunique{$tested}} ];
+    my @unique_to_this_index = ();
+    for my $s (@seenthis) {
+        push @unique_to_this_index, $s
+            unless $seen_in_all_others{$s};
+    }
+    return \@unique_to_this_index;
 }
 
 sub get_complement {
@@ -527,8 +517,8 @@ List::Compare::Functional - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.44 of List::Compare::Functional.
-This version was released February 15 2015.  The first released
+This document refers to version 0.45 of List::Compare::Functional.
+This version was released February 16 2015.  The first released
 version of List::Compare::Functional was v0.21.  Its version numbers
 are set to be consistent with the other parts of the List::Compare
 distribution.
@@ -1692,7 +1682,7 @@ James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare::Functional' or 'List-Compare-Functional' in your
 subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 15 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 16 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
